Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(517)

Unified Diff: runtime/bin/platform.h

Issue 11275281: Update dart:io to convert strings between UTF8 and current code page (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Address comments Created 8 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/bin/main.cc ('k') | runtime/bin/platform.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/bin/platform.h
diff --git a/runtime/bin/platform.h b/runtime/bin/platform.h
index 233740ecb3b3a0bb8a65924a1a7083f0986a3ed3..38cafbe2ad84b3953e005bb8ae25320a5feb3f8a 100644
--- a/runtime/bin/platform.h
+++ b/runtime/bin/platform.h
@@ -27,11 +27,12 @@ class Platform {
// Extracts the local hostname.
static bool LocalHostname(char* buffer, intptr_t buffer_length);
// Extracts the environment variables for the current process.
// The array of strings returned must be deallocated using
// delete[]. The number of elements in the array is returned
// in the count argument.
static char** Environment(intptr_t* count);
+ static void FreeEnvironment(char** env, intptr_t count);
private:
DISALLOW_ALLOCATION();
« no previous file with comments | « runtime/bin/main.cc ('k') | runtime/bin/platform.cc » ('j') | no next file with comments »
@@ -27,11 +27,12 @@ class Platform {
// Extracts the local hostname.
static bool LocalHostname(char* buffer, intptr_t buffer_length);
- // Extracts the environment variables for the current process.
- // The array of strings returned must be deallocated using
- // delete[]. The number of elements in the array is returned
+ // Extracts the environment variables for the current process. The
+ // array of strings returned must be deallocated using
+ // FreeEnvironment. The number of elements in the array is returned
// in the count argument.
static char** Environment(intptr_t* count);

Powered by Google App Engine
This is Rietveld 408576698